@@ -135,9 +135,12 @@ int read_shell_config( ShellOptions_t *opts, const char *filename, int do_log )
 	log = do_log;
 	memset(line, 0, CFG_LINE_LEN + 1);
         cfg_file = fopen(filename, "r");
-        if (!cfg_file && log ) {
-		log_set_priority(LOG_WARNING);
-		log_msg("config file (%s) missing, using defaults", filename);
+        if (!cfg_file) {
+		if (log){
+			log_set_priority(LOG_WARNING);
+			log_msg("config file (%s) missing, using defaults", 
+				filename);
+		}
                 opts->shell_flags = RSSH_ALLOW_SCP;
 		return FALSE;
         }
